/*
 * Pipe accessor object functionality.
 *
 * Copyright (C) 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "accessor.h"



/* Flexpage storage methods for pipe accessors merely provide empty flexpages
   and do not fill or flush flexpage data. */

void PipePagingAccessor::fill_flexpage_data(Flexpage *flexpage)
{
  flexpage->clear();
}

void PipePagingAccessor::flush_flexpage_data(Flexpage *)
{
}



/* Accessor linking methods for pipe accessors. */

PipePagingAccessor *PipePagingAccessor::new_accessor()
{
  if (!_next)
  {
    _next = new PipePagingAccessor(_paging);
    _next->attach();
    _next->attach();
  }
  return _next;
}

PipePagingAccessor *PipePagingAccessor::next_accessor()
{
  return _next;
}
